==============
russianpodcast
==============


.. image:: https://img.shields.io/pypi/v/russianpodcast.svg
        :target: https://pypi.python.org/pypi/russianpodcast

.. image:: https://img.shields.io/travis/cgte/russianpodcast.svg
        :target: https://travis-ci.org/cgte/russianpodcast

.. image:: https://readthedocs.org/projects/russianpodcast/badge/?version=latest
        :target: https://russianpodcast.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Fetches podcasts from russianpodcast.eu automatically


* Free software: GNU General Public License v3
* Documentation: https://russianpodcast.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
